﻿using BPA.Common.Enums.CRM;
using BPA.Component.DTOCommon.BaseDTOs;
using BPA.SaaS.Stock.Api.DTO;

namespace BPA.SaaS.Stock.Api.IService.Product;

/// <summary>
/// 原料
/// </summary>
public interface IProductService
{
    /// <summary>
    /// 查询物料信息
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    Task<BaseResultPage<ProductListQuery>> GetProductList(ProductListQuery dto);

    /// <summary>
    /// 获取产品列表
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    Task<BaseResultPage<ProductListByCodeQuery>> GetProductListBySrdId(ProductListDto dto);

    /// <summary>
    /// 添加产品
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    Task<BaseResult<bool>> AddProduct(ProductInfoDto dto);

    /// <summary>
    /// 更新产品
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    Task<BaseResult<bool>> UpdateProduct(ProductInfoDto dto);

    /// <summary>
    /// 批量删除物料信息
    /// </summary>
    /// <param name="Ids"></param>
    /// <returns></returns>
    Task<BaseResult<bool>> BatchDelProduct(List<string> Ids);

    /// <summary>
    /// 更新产品状态
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    Task<bool> UpdateProductStatus(ProductInfoDto dto);

    /// <summary>
    /// 根据物料类型、单位编号判断物料单位是否可以修改、删除或禁用
    /// </summary>
    /// <param name="ids">物料类型编号或者物料单位编号编号</param>
    /// <param name="typeValue">1:表示类型,2:单位</param>
    /// <param name="status">为空表示删除,不为空表示修改</param>
    /// <returns></returns>
    Task<BaseResult<List<ProductInfoDto>>> IsModifyOrDel(string[] ids, string typeValue, EnumCommonStatus? status);

    /// <summary>
    /// 获取产品明细
    /// </summary>
    /// <param name="productID"></param>
    /// <returns></returns>
    Task<BaseResult<List<ProductDetailedDto>>> GetProductCode(string productID);
}