﻿using BPA.Component.DbClient;
using BPA.Component.DbClient.RepositoryModel;
using BPA.Component.DTOCommon.BaseDTOs;
using BPA.Component.Extensions;
using BPA.SaaS.Stock.Api.DTO;
using BPA.SaaS.Stock.Api.DTO.Product;
using BPA.SaaS.Stock.Api.Entity;
using BPA.SaaS.Stock.Api.IRepository.Product;
using BPA.SaaS.Stock.Api.Model;

namespace BPA.SaaS.Stock.Api.Repository.Product;

public class ProductCodeRepository : BaseDbRepository<StockDbSugarClient, BPA_ProductCode>, IProductCodeRepository
{
    public ProductCodeRepository(StockDbSugarClient dbClient) : base(dbClient)
    {
    }

    public async Task<BaseResultPage<ProductCodeDto>> GetProductList(ProductCodeListQuery dto)
    {
        var total = 0;

        var rows = await SimpleClient.AsQueryable()
            .Where(a => a.IsDeleted == false)
            .WhereIF(dto.Code.IsNotEmpty(), code => code.Code == dto.Code)
            .WhereIF(dto.Id.IsNotEmpty(), code => code.ProductID == dto.Code)
            // where etc..
            .ToPageListAsync(dto.Current, dto.PageSize, total);

        var result = rows.MapToList<ProductCodeDto, BPA_ProductCode>().ToList();
        return BaseResultPage<ProductCodeDto>.BuildOK(result, total);
    }
}