﻿using BPA.Component.WebApiExtensions.SimpleJWT;
using BPA.SaaS.Basic.Api.DTO;
using BPA.SaaS.Basic.Api.DTO.InnerEnum;
using BPA.SaaS.Basic.Api.SDK;

namespace BPA.SaaS.Stock.Api.UnitTest;

public class AuthBasicToken : BaseUnitTest
{
    private readonly BasicWebApiSDK _basicWebApiSDK;

    public AuthBasicToken()
    {
        _basicWebApiSDK = GetService<BasicWebApiSDK>();
    }

    public async Task<ClaimInfo> GetClaimInfo(string userName, string password)
    {
        var result = await _basicWebApiSDK.AuthServiceApi.LoginAsync(EnumLoginType.FranchiseeUsers, new LoginInput
        {
            Account = userName,
            Password = password,
            Name = "",
            RoleId = ""
        });
        if (!result.IsOK) throw new Exception("登录失败");

        var jsonToken = JWTEncryption.ReadJwtToken(result.Data.token);
        return new ClaimInfo
        {
            UserId = jsonToken.Claims.First(f => f.Type == "UserId").Value,
            Account = jsonToken.Claims.First(f => f.Type == "Account").Value,
            Name = jsonToken.Claims.First(f => f.Type == "Name").Value,
            SuperAdmin = jsonToken.Claims.First(f => f.Type == "SuperAdmin").Value == "1",
            LoginType = Convert.ToInt32(jsonToken.Claims.First(f => f.Type == "LoginType").Value),
            GroupId = jsonToken.Claims.First(f => f.Type == "GroupId").Value,
            OrgId = jsonToken.Claims.FirstOrDefault(f => f.Type == "OrgId")?.Value
        };
    }

    public async Task<string> GetToken(string userName, string password)
    {
        var result = await _basicWebApiSDK.AuthServiceApi.LoginAsync(EnumLoginType.FranchiseeUsers, new LoginInput
        {
            Account = userName,
            Password = password,
            Name = "",
            RoleId = ""
        });
        if (!result.IsOK) throw new Exception("登录失败");

        return result.Data.token.ToBearer();
    }
}