﻿using Autofac;
using Autofac.Extensions.DependencyInjection;
using BPA.Component.ApolloClient;
using BPA.SaaS.Stock.Api.Bootstrap;
using BPA.SaaS.Stock.Api.Model;
using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.DependencyInjection;

namespace BPA.SaaS.Stock.Api.UnitTest
{
    /// <summary>
    /// 测试基类
    /// </summary>
    public class BaseUnitTest
    {
#pragma warning disable CS8618
        private static ILifetimeScope lifetimeScope;
#pragma warning restore CS8618

        public BaseUnitTest()
        {
            var builder = new ConfigurationBuilder();
            builder.AddEnvironmentVariables();
            Environment.SetEnvironmentVariable("ASPNETCORE_ENVIRONMENT", "Development");
            Environment.SetEnvironmentVariable("APOLLO_META_SERVER_URL", "http://10.2.1.21:28080");
            Environment.SetEnvironmentVariable("APOLLO_COMMON_NAMESPACE", "DEV.Common");
            Environment.SetEnvironmentVariable("APP_NAME", "BPA.SaaS.Basic.Api");
            var configuration = builder.Build();
            configuration.SetupConfiguration();

            var services = new ServiceCollection();
            services.AddApollo<StockApiConfig>();
            services.AddBPAMiddlewareServices(new[] {"null arg"});
            services.AddSingleton<AuthBasicToken>();
            services.AddServiceSDK(configuration);

            var factory = new AutofacServiceProviderFactory();
            var containerBuild = factory.CreateBuilder(services);
            containerBuild.SetupConfigureContainer();
            containerBuild.RegisterBuildCallback(scope => lifetimeScope = scope);
            var serviceProvider = factory.CreateServiceProvider(containerBuild);
            serviceProvider.PreHeatRun();

            // var db = serviceProvider.CreateScope().ServiceProvider.GetService<BasicDbSugarClient>();
        }

        /// <summary>
        /// 从容器中获取对象
        /// </summary>
        /// <typeparam name="T"></typeparam>
        /// <returns></returns>
        protected static T GetService<T>() where T : notnull => lifetimeScope.Resolve<T>();
    }
}