﻿using BPA.Common.Enums.CRM;
using BPA.Component.DTOCommon.BaseDTOs;
using BPA.SaaS.Stock.Api.DTO;
using BPA.SaaS.Stock.Api.IService.Product;
using Microsoft.AspNetCore.Mvc;

namespace BPA.SaaS.Stock.Api.WebApi.Product;

[ApiController]
[Route("api/[controller]/[action]")]
public class ProductController : ControllerBase
{
    private readonly IProductService _product;

    public ProductController(IProductService product)
    {
        _product = product;
    }

    /// <summary>
    /// 查询物料信息
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    [HttpPost]
    public Task<BaseResultPage<ProductListQuery>> GetProductList(ProductListQuery dto) => _product.GetProductList(dto);

    /// <summary>
    /// 获取产品列表
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    [HttpPost]
    public Task<BaseResultPage<ProductListByCodeQuery>> GetProductListBySrdId(ProductListDto dto) => _product.GetProductListBySrdId(dto);

    /// <summary>
    /// 添加产品
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    [HttpPost]
    public Task<BaseResult<bool>> AddProduct(ProductInfoDto dto) => _product.AddProduct(dto);

    /// <summary>
    /// 更新产品
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    [HttpPost]
    public Task<BaseResult<bool>> UpdateProduct(ProductInfoDto dto) => _product.UpdateProduct(dto);

    /// <summary>
    /// 批量删除物料信息
    /// </summary>
    /// <param name="Ids"></param>
    /// <returns></returns>
    [HttpPost]
    public Task<BaseResult<bool>> BatchDelProduct(List<string> Ids) => _product.BatchDelProduct(Ids);

    /// <summary>
    /// 更新产品状态
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    [HttpPost]
    public Task<bool> UpdateProductStatus(ProductInfoDto dto) => _product.UpdateProductStatus(dto);

    /// <summary>
    /// 根据物料类型、单位编号判断物料单位是否可以修改、删除或禁用
    /// </summary>
    /// <param name="ids">物料类型编号或者物料单位编号编号</param>
    /// <param name="typeValue">1:表示类型,2:单位</param>
    /// <param name="status">为空表示删除,不为空表示修改</param>
    /// <returns></returns>
    [HttpGet]
    public Task<BaseResult<List<ProductInfoDto>>> IsModifyOrDel(string[] ids, string typeValue, EnumCommonStatus? status) => _product.IsModifyOrDel(ids, typeValue, status);

    /// <summary>
    /// 获取产品明细
    /// </summary>
    /// <param name="productID"></param>
    /// <returns></returns>
    [HttpGet]
    public Task<BaseResult<List<ProductDetailedDto>>> GetProductCode(string productID) => _product.GetProductCode(productID);
}